// Three intersecting cylinders
// Ed Nisley KE4ZNU - Oct 2011

Layout = "Build";			// Show Build

include <lib/visibone_colors.scad>

//- Extrusion parameters must match reality!
//  Print with +1 shells and 3 solid layers
//  Use infill solidity = 0.5 or more...

ThreadThick = 0.25;
ThreadWidth = 2.0 * ThreadThick;

HoleWindage = 0.2;

Protrusion = 0.1;			// make holes end cleanly

//------ Model dimensions

CylDia = 2*IntegerMultiple(40.0/2,ThreadThick);
CylRad = CylDia/2;

echo(str("Actual diameter: ",CylDia));

Angle = [45,0,0];			// rotate to choose build orientation

$fn=128;

AlignPegDia = 2.90;

//-------

function IntegerMultiple(Size,Unit) = Unit * ceil(Size / Unit);

module PolyCyl(Dia,Height,ForceSides=0) {			// based on nophead's polyholes

  Sides = (ForceSides != 0) ? ForceSides : (ceil(Dia) + 2);

  FixDia = Dia / cos(180/Sides);

  cylinder(r=(FixDia + HoleWindage)/2,h=Height,$fn=Sides);
}

module ShowPegGrid(Space = 10.0,Size = 1.0) {

  Range = floor(50 / Space);

	for (x=[-Range:Range])
	  for (y=[-Range:Range])
		translate([x*Space,y*Space,Size/2])
		  %cube(Size,center=true);

}

//------- Model bits & pieces

module OneCyl(Alignment) {
  rotate(Alignment)
    cylinder(r=CylRad,h=CylDia,center=true);
}

module ThreeCyl() {
  intersection() {
	OneCyl([0,0,0]);
	OneCyl([90,0,0]);
	OneCyl([0,90,0]);
  }
}

module HemiThing() {
  difference() {
	rotate(Angle)
	  ThreeCyl();
	translate([0,0,-CylRad])
		cube(CylDia,center=true);
	for (Index = [0:3])
	  rotate(Index*90)
		translate([CylRad/2,0,-Protrusion])
		  PolyCyl(AlignPegDia,5+Protrusion);
  }
}

//---------

ShowPegGrid();

if (Layout == "Show")
  color(LOY) ThreeCyl();

if (Layout == "Build") {
  translate([CylRad,CylRad,0])
	color(LOY) HemiThing();

  translate([-CylRad,-CylRad,0])
	color(LOY) HemiThing();
}